INFINITY = float('inf')

# Default threshold: lower means to ignore more.
DEFAULT_THRESHOLD = 100
# Default verbosity. Zero means quiet.
DEFAULT_VERBOSITY = 1
MAX_VERBOSITY = 3
# Resolution (in dots per inch) in which to render pages
DEFAULT_DPI = 50
# Default number of parallel threads
DEFAULT_NUM_THREADS = 2

# Minimum verbosity for printing what the result is, and why
VERB_PRINT_REASON=1
# Minimum verbosity for doing sanity warnings
VERB_WARN_SANITY=1
# Minimum verbosity for printing what the temporary directory is
VERB_PRINT_TMPDIR=1
# Minimum verbosity for printing rough progress
VERB_ROUGH_PROGRESS=1
# Minimum verbosity for printing the significance for each page
VERB_PERPAGE=2
# Minimum verbosity for printing commands
VERB_PRINT_CMD=3

# Maximum number of differing pages to report
MAX_REPORT_PAGENOS=5